Dynamics GP Anypoint&trade; Connector Demo - Customer, Sales Invoice and Purchase Order CRUD
==========================================================

## Introduction

The present demo application provides a **complete workflow** to sequentially invoke some of Dynamics's GP **standard operations**.

## Prerequisites

* Java 7 or higher
* Anypoint Studio 5.4.x or higher
* Mule Runtime 3.7.x EE or higher
* DataWeave
* Access to a Dynamics GP Web service configured for NTLM or Kerberos.

## Import the project

* Go to **File > Import**
* Select **Anypoint Studio Project from External Location** (under the parent folder "Anypoint Studio")

    ![Import Menu](images/dynamics-gp-import-menu.png)

* Provide the root path to the demo project folder.
* Select Mule Runtime (3.7.x EE).

    ![File Selection](images/dynamics-gp-import-file.png)

* Click **Finish**.
* Set Dynamics credentials inside the file `src/main/app/mule-app.properties`. This may vary depending on the selected connection configuration. The current demo uses **Kerberos Connection**:

    ```
    gp-kerberos.username=
    gp-kerberos.password=
    gp-kerberos.endpoint=
    gp-kerberos.spn=
    gp-kerberos.loginConfLocation=
    gp-kerberos.krb5ConfLocation=
    ```

Please check the user-manual.adoc file for information about the Kerberos and NTLM connection properties.

* Open the **Global Element Configuration**.

    ![Global Element](images/kerberos-connection.png)

* Click the **Test Connection** button to ensure there is connectivity with the sandbox. A successful message should pop-up.

    ![Test Connection](images/dynamics-gp-connection-test.png)

* Open a browser and access the URL **http://localhost:8082/app**. You should see the demo application deployed:

    ![Demo Index](images/dynamics-gp-main-page.png)

## About the flows

* **Create Customer:** Creates a new Customer.

    ![Create Customer](images/create-customer-flow.png)

* **Get Customer:** Retrieves the complete metadata of a Customer given its ID.

    ![Get Customer](images/get-customer-flow.png)

* **Update Customer:** Updates a Customer's comment.

    ![Update Customer](images/update-customer-flow.png)

* **Delete Customer:** Removes a Customer given its ID.

    ![Delete Customer](images/delete-customer-flow.png)

* **Get Customers:** Retrieves Customers filtering by Customer Name.

    ![Get Customers](images/get-customer-list-flow.png)



* **Create Sales Invoice:** Creates a new Sales Invoice given a unique Sales Invoice, customer, batch, item and company keys and quantity.

    ![Create Sales Invoice](images/create-sales-invoice-flow.png)

* **Delete Sales Invoice:** Removes a Sales Invoice given its ID.

    ![Delete Sales Invoice](images/delete-sales-invoice-flow.png)


* **Get Sales Invoices:** Retrieves sales Invoices filtering by Customer ID.

    ![Get Sales Invoices](images/get-sales-invoice-list-flow.png)


* **Create Purchase Order:**  given a key, a vendor, a quantity, an item number, and a warehouse key creates a new Purchase Order.

    ![Create Purchase Order](images/create-purchase-order-flow.png)

* **Delete Purchase Order:** Removes a Purchase Order
given its ID.

    ![Delete Purchase Order](images/delete-purchase-order-flow.png)

* **Get Purchase Orders:** Retrieves Purchase Orders filtering by Vendor ID.

    ![Get Purchase Orders](images/get-purchase-order-list-flow.png)


## Run the demo

### Create Customer

![Demo Create Customer](images/run-demo/CreateCustomer.png)

* Provide a **Customer Name** and **Customer Id** for the new Customer.
* Set the Company Key on which create the new Customer. Default Company ID is -1.
* Click the button **Create** and wait a few moments to finish processing.
* If successfully created you should see a success message in an Alert.

### Get Customer

![Demo Get Customer](images/run-demo/GetCustomer.png)

* Provide the **Customer Id** of an existing Customer.
* Click the button **Get** and wait a few moments to finish processing.
* If found, the metadata of the file will be displayed inside the textarea below the button.

### Update Customer

![Demo Update Customer](images/run-demo/UpdateCustomer.png)

* Provide the **Customer Id** of an existing Customer.
* Provide a **Customer Comment**. This value is going to be used to make the Customer's update.
* Click the button **Update** and wait a few moments to finish processing.
* You should see a success message in an Alert.


### Delete Customer

![Demo Delete Customer](images/run-demo/DeleteCustomer.png)

* Provide the **Customer Id** of an existing Customer.
* Click the button **Delete** and wait a few moments to finish processing if success you should see a success message in an Alert.

### Get Customers

![Demo Get Customers](images/run-demo/GetCustomers.png)

* Provide a **Name Filter**, this value is going to be used to filter the retrieved Customers by name.
* Click the button **Get List** and wait a few moments to finish processing.
* You should see the some information of the retrieved customers in the table below the Get List button.


### Create Sales Invoice

![Create Sales Invoice](images/run-demo/CreateSalesInvoice.png)

* Provide a **Sales Invoice Key**.
* Provide a **Customer Key**.
* Provide a **Batch Key**, **Item Key**, **Quantity** for the new Sales Invoice.
* Set the Company Key on which create the new Sales Invoice. Default is -1.
* Click the button **Create** and wait a few moments to finish processing.
* If successfully created you should see a success message in an Alert.


### Delete Sales Invoice

![Delete Sales Invoice](images/run-demo/DeleteSalesInvoice.png)

* Provide the **SalesInvoice Key** of an existing Sales Invoice.
* Set the **Company Key** of the company at which belongs the Sales Invoice.
* Click the button **Delete** and wait a few moments to finish processing.
* If success you should see a success message in an Alert.

### Get Sales Invoices

![Get Sales Invoices](images/run-demo/GetSalesInvoices.png)

* Provide a **Customer Id Filter**, this value is going to be used to filter Sales Invoices.
* Click the button **Get List** and wait a few moments to finish processing.
* You should see the some information of the retrieved Sales Invoices in the table below the Get List button.


### Create Purchase Order

![Create Purchase Order](images/run-demo/CreatePurchaseOrder.png)

* Provide a **Purchase Order Key**.
* Provide a **Vendor Key**.
* Provide a **Quantity**, **Item Vendor Number** and **Warehouse key** for the new Purchase Order.
* Set the Company Key on which create the new Sales Invoice.
* Click the button **Create** and wait a few moments to finish processing.
* If successfully created you should see a success message in an Alert:


### Delete Purchase Order

![Delete Purchase Order](images/run-demo/DeletePurchaseOrder.png)

* Provide a **Purchase Order Key** of an existing Purchase Order.
* Click the button **Delete** and wait a few moments to finish processing.
* You should see a success message in an Alert:

### Get Purchase Orders

![Get Purchase Orders](images/run-demo/GetPurchaseOrders.png)

* Provide a **Vendor Id Filter**, this value is going to be used to filter the Purchase orders by Vendor ID.
* Click the button **Get List** and wait a few moments to finish processing.
* You should see the some information of the retrieved Purchase Orders in the table below the Get List button.


## See more

* For additional technical information on the DynammicsGP Connector, visit our [technical reference documentation](http://mulesoft.github.io/ms-dynamics-gp-connector/) or refer to the [Dynamics GP Documentation Site](https://docs.mulesoft.com/mule-user-guide/v/3.8/ms-dynamics-gp-connector).
* For more information on the Dynamics GP API, go to the [Dynamics GP Web Service documentation page](https://msdn.microsoft.com/en-us/library/cc534132.aspx).
